@@ -20,6 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 
 #include "pango-engine.h"
@@ -312,7 +313,7 @@ hangul_engine_shape (PangoEngineShape *engine,
   const char *p, *start;
 
   gunichar jamos_static[8];
-  guint max_jamos = G_N_ELEMENTS (jamos_static);
+  gint max_jamos = G_N_ELEMENTS (jamos_static);
   gunichar *jamos = jamos_static;
   int n_jamos;
 
