@@ -19,11 +19,21 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
 #include "pango-ot-private.h"
 
 #define PANGO_SCALE_26_6 (PANGO_SCALE / (1<<6))
 #define PANGO_UNITS_26_6(d) (PANGO_SCALE_26_6 * (d))
 
+/**
+ * pango_ot_buffer_new
+ * @font: a #PangoFcFont
+ *
+ * Return value: the new #PangoOTBuffer
+ *
+ * Since: 1.4
+ **/ 
 PangoOTBuffer *
 pango_ot_buffer_new (PangoFcFont *font)
 {
@@ -33,7 +43,7 @@ pango_ot_buffer_new (PangoFcFont *font)
    * probably already have the font locked, however,
    * so there is little performance penalty.
    */
-  PangoOTBuffer *buffer = g_new (PangoOTBuffer, 1);
+  PangoOTBuffer *buffer = g_slice_new (PangoOTBuffer);
   FT_Face face = pango_fc_font_lock_face (font);
 
   if (otl_buffer_new (face->memory, &buffer->buffer) != FT_Err_Ok)
@@ -49,14 +59,26 @@ pango_ot_buffer_new (PangoFcFont *font)
   return buffer;
 }
 
+/**
+ * pango_ot_buffer_destroy
+ * @buffer: a #PangoOTBuffer
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_destroy (PangoOTBuffer *buffer)
 {
   otl_buffer_free (buffer->buffer);
   g_object_unref (buffer->font);
-  g_free (buffer);
+  g_slice_free (PangoOTBuffer, buffer);
 }
 
+/**
+ * pango_ot_buffer_clear
+ * @buffer: a #PangoOTBuffer
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_clear (PangoOTBuffer *buffer)
 {
@@ -64,6 +86,15 @@ pango_ot_buffer_clear (PangoOTBuffer *buffer)
   buffer->applied_gpos = FALSE;
 }
 
+/**
+ * pango_ot_buffer_add_glyph
+ * @buffer: a #PangoOTBuffer
+ * @glyph_index:
+ * @properties:
+ * @cluster: 
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_add_glyph (PangoOTBuffer *buffer,
 			   guint          glyph_index,
@@ -75,6 +106,13 @@ pango_ot_buffer_add_glyph (PangoOTBuffer *buffer,
 
 }
 
+/**
+ * pango_ot_buffer_set_rtl
+ * @buffer: a #PangoOTBuffer
+ * @rtl: %TRUE for right-to-left 
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_set_rtl (PangoOTBuffer *buffer,
 			 gboolean       rtl)
@@ -102,6 +140,14 @@ pango_ot_buffer_set_zero_width_marks (PangoOTBuffer     *buffer,
   buffer->zero_width_marks = zero_width_marks != FALSE;
 }
 
+/**
+ * pango_ot_buffer_get_glyphs
+ * @buffer: a #PangoOTBuffer
+ * @glyphs: 
+ * @n_glyphs:
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_get_glyphs (PangoOTBuffer  *buffer,
 			    PangoOTGlyph  **glyphs,
@@ -204,6 +250,13 @@ apply_gpos_rtl (PangoGlyphString *glyphs,
     }
 }
 
+/**
+ * pango_ot_buffer_output
+ * @buffer: a #PangoOTBuffer
+ * @glyphs: a #PangoGlyphString
+ *
+ * Since: 1.4
+ **/ 
 void
 pango_ot_buffer_output (PangoOTBuffer    *buffer,
 			PangoGlyphString *glyphs)
