@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -60,7 +61,7 @@ pango_context_init (PangoContext *context)
   context->font_map = NULL;
 
   context->font_desc = pango_font_description_new ();
-  pango_font_description_set_family (context->font_desc, "serif");
+  pango_font_description_set_family_static (context->font_desc, "serif");
   pango_font_description_set_style (context->font_desc, PANGO_STYLE_NORMAL);
   pango_font_description_set_variant (context->font_desc, PANGO_VARIANT_NORMAL);
   pango_font_description_set_weight (context->font_desc, PANGO_WEIGHT_NORMAL);
@@ -111,8 +112,7 @@ pango_context_finalize (GObject *object)
  * gdk_pango_context_get_for_screen(), and 
  * gtk_widget_get_pango_context().
  * 
- * Return value: the newly allocated #PangoContext, which should
- *               be freed with g_object_unref().
+ * Return value: the new #PangoContext
  **/
 PangoContext *
 pango_context_new (void)
@@ -160,7 +160,7 @@ pango_context_set_matrix (PangoContext       *context,
  * Gets the transformation matrix that will be applied when
  * rendering with this context. See pango_context_set_matrix().
  *
- * Return value: the matrix, or %NULL if no matrix has been set
+ * Returns: the matrix, or %NULL if no matrix has been set
  *  (which is the same as the identity matrix). The returned
  *  matrix is owned by Pango and must not be modified or
  *  freed.
@@ -451,7 +451,7 @@ shaper_font_element_destroy (ShaperFontElement *element)
 {
   if (element->font)
     g_object_unref (element->font);
-  g_free (element);
+  g_slice_free (ShaperFontElement, element);
 }
 
 static ShaperFontCache *
@@ -503,7 +503,7 @@ shaper_font_cache_insert (ShaperFontCache   *cache,
 			  PangoEngineShape  *shape_engine,
 			  PangoFont         *font)
 {
-  ShaperFontElement *element = g_new (ShaperFontElement, 1);
+  ShaperFontElement *element = g_slice_new (ShaperFontElement);
   element->shape_engine = shape_engine;
   element->font = font;
   
@@ -660,11 +660,7 @@ itemize_state_init (ItemizeState      *state,
   /* First, apply the bidirectional algorithm to break
    * the text into directional runs.
    */
-  text_ucs4 = g_utf8_to_ucs4_fast (text + start_index, length, &n_chars);
-  state->embedding_levels = g_new (guint8, n_chars);
-  pango_log2vis_get_embedding_levels (text_ucs4, n_chars, &base_dir,
-                                      state->embedding_levels);
-  g_free (text_ucs4);
+  state->embedding_levels = pango_log2vis_get_embedding_levels (text + start_index, length, &base_dir);
   
   state->embedding_end_offset = 0;
   state->embedding_end = text + start_index;
@@ -1372,7 +1368,7 @@ update_metrics_from_items (PangoFontMetrics *metrics,
  * be a composite of the metrics for the fonts loaded for the
  * individual families.
  *
- * Return value: a #PangoFontMetrics object. The caller must call pango_font_metrics_unref()
+ * Returns: a #PangoFontMetrics object. The caller must call pango_font_metrics_unref()
  *   when finished using the object.
  **/
 PangoFontMetrics *
