@@ -19,16 +19,17 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <pango-attributes.h>
 #include <pango-item.h>
+#include <pango-utils.h>
 
 /**
  * pango_item_new:
  * 
  * Creates a new #PangoItem structure initialized to default values.
  * 
- * Return value: the newly allocated #PangoItem, which should
- *               be freed with pango_item_free().
+ * Return value: the new #PangoItem
  **/
 PangoItem *
 pango_item_new (void)
@@ -44,8 +45,7 @@ pango_item_new (void)
  * 
  * Copy an existing #PangoItem structure.
  * 
- * Return value: the newly allocated #PangoItem, which should
- *               be freed with pango_item_free().
+ * Return value: the new #PangoItem
  **/
 PangoItem *
 pango_item_copy (PangoItem *item)
@@ -101,7 +101,7 @@ pango_item_get_type (void)
   static GType our_type = 0;
   
   if (our_type == 0)
-    our_type = g_boxed_type_register_static ("PangoItem",
+    our_type = g_boxed_type_register_static (I_("PangoItem"),
                                              (GBoxedCopyFunc) pango_item_copy,
                                              (GBoxedFreeFunc) pango_item_free);
   return our_type;
@@ -124,8 +124,7 @@ pango_item_get_type (void)
  * item isn't available, so pango_item_split() can't count the char
  * length of the split items itself.
  * 
- * Return value: new item representing text before @split_index, which
- *               should be freed with pango_item_free().
+ * Return value: new item representing text before @split_index
  **/
 PangoItem*
 pango_item_split (PangoItem  *orig,
