@@ -27,6 +27,8 @@
 
 G_BEGIN_DECLS
 
+#define PANGO_CAIRO_UNKNOWN_FLAG 0x10000000
+
 #define PANGO_CAIRO_FONT_MAP_GET_IFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), PANGO_TYPE_CAIRO_FONT_MAP, PangoCairoFontMapIface))
 
 typedef struct _PangoCairoFontMapIface PangoCairoFontMapIface;
@@ -58,12 +60,18 @@ struct _PangoCairoFontIface
 
   void (*install) (PangoCairoFont *font,
 		   cairo_t        *cr);
+
+  cairo_font_face_t *(*get_font_face) (PangoCairoFont *font);
+
+  cairo_scaled_font_t *(*get_scaled_font) (PangoCairoFont *font);
 };
 
 GType pango_cairo_font_get_type (void);
 
 void _pango_cairo_font_install (PangoCairoFont *font,
 				cairo_t        *cr);
+cairo_font_face_t *_pango_cairo_font_get_font_face (PangoCairoFont *font);
+cairo_scaled_font_t *_pango_cairo_font_get_scaled_font (PangoCairoFont *font);
 
 #define PANGO_TYPE_CAIRO_RENDERER            (pango_cairo_renderer_get_type())
 #define PANGO_CAIRO_RENDERER(object)         (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_CAIRO_RENDERER, PangoCairoRenderer))
@@ -76,6 +84,25 @@ GType pango_cairo_renderer_get_type    (void);
 const cairo_font_options_t *_pango_cairo_context_get_merged_font_options (PangoContext *context);
 
 
+typedef struct _PangoCairoHexBoxInfo PangoCairoHexBoxInfo;
+
+struct _PangoCairoHexBoxInfo
+{
+	PangoFont *font;
+	double digit_width;
+	double digit_height;
+	double pad;
+	double box_descent;
+	double box_height;
+};
+
+PangoCairoHexBoxInfo *_pango_cairo_get_hex_box_info (PangoCairoFont *font);
+
+void _pango_cairo_get_glyph_extents_missing (PangoCairoFont *cfont,
+					     PangoGlyph      glyph,
+					     PangoRectangle *ink_rect,
+					     PangoRectangle *logical_rect);
+
 G_END_DECLS
 
 #endif /* __PANGOCAIRO_PRIVATE_H__ */
