@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <glib.h>
 #include <stdio.h>
@@ -262,7 +262,7 @@ pango_ft2_get_context (double dpi_x, double dpi_y)
  * global PangoFT2 fontmap is deprecated; use pango_ft2_font_map_new()
  * instead.
  *
- * Return value: a #PangoFT2FontMap.
+ * Returns: a #PangoFT2FontMap.
  **/
 PangoFontMap *
 pango_ft2_font_map_for_display (void)
