@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -58,10 +58,6 @@ static void                   pango_ft2_font_get_glyph_extents (PangoFont      *
 
 static FT_Face    pango_ft2_font_real_lock_face         (PangoFcFont      *font);
 static void       pango_ft2_font_real_unlock_face       (PangoFcFont      *font);
-static gboolean   pango_ft2_font_real_has_char          (PangoFcFont      *font,
-							 gunichar          wc);
-static guint      pango_ft2_font_real_get_glyph         (PangoFcFont      *font,
-							 gunichar          wc);
 static PangoGlyph pango_ft2_font_real_get_unknown_glyph (PangoFcFont      *font,
 							 gunichar          wc);
 
@@ -263,8 +259,6 @@ pango_ft2_font_class_init (PangoFT2FontClass *class)
   
   fc_font_class->lock_face = pango_ft2_font_real_lock_face;
   fc_font_class->unlock_face = pango_ft2_font_real_unlock_face;
-  fc_font_class->has_char = pango_ft2_font_real_has_char;
-  fc_font_class->get_glyph = pango_ft2_font_real_get_glyph;
   fc_font_class->get_unknown_glyph = pango_ft2_font_real_get_unknown_glyph;
 }
 
@@ -366,34 +360,6 @@ pango_ft2_font_real_unlock_face (PangoFcFont *font)
 {
 }
 
-static gboolean
-pango_ft2_font_real_has_char (PangoFcFont *font,
-			      gunichar     wc)
-{
-  FcCharSet *charset;
-
-  if (FcPatternGetCharSet (font->font_pattern,
-                           FC_CHARSET, 0, &charset) != FcResultMatch)
-    return FALSE;
-
-  return FcCharSetHasChar (charset, wc);
-}
-
-static guint
-pango_ft2_font_real_get_glyph (PangoFcFont *font,
-			       gunichar     wc)
-{
-  FT_Face face;
-  FT_UInt index;
-
-  face = pango_ft2_font_get_face ((PangoFont *)font);
-  index = FcFreeTypeCharIndex (face, wc);
-  if (index && index <= face->num_glyphs)
-    return index;
-
-  return 0;
-}
-
 static PangoGlyph
 pango_ft2_font_real_get_unknown_glyph (PangoFcFont *font,
 				       gunichar     wc)
@@ -402,7 +368,9 @@ pango_ft2_font_real_get_unknown_glyph (PangoFcFont *font,
 }
 
 static gboolean
-pango_ft2_free_glyph_info_callback (gpointer key, gpointer value, gpointer data)
+pango_ft2_free_glyph_info_callback (gpointer key,
+				    gpointer value,
+				    gpointer data)
 {
   PangoFT2Font *font = PANGO_FT2_FONT (data);
   PangoFT2GlyphInfo *info = value;
@@ -500,7 +468,10 @@ _pango_ft2_ft_strerror (FT_Error error)
     return found->msg;
   else
     {
-      static char default_msg[100];
+      static char *default_msg = NULL;
+
+      if (!default_msg)
+        default_msg = g_malloc (60);
 
       g_sprintf (default_msg, "Unknown FreeType2 error %#x", error);
       return default_msg;
