@@ -21,7 +21,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <ctype.h>
 #include <stdio.h>
@@ -207,7 +207,7 @@ pango_win32_font_map_class_init (PangoWin32FontMapClass *class)
  * not be freed. If the font map is no longer needed, it can
  * be released with pango_win32_shutdown_display().
  *
- * Return value: a #PangoFontMap.
+ * Returns: a #PangoFontMap.
  **/
 PangoFontMap *
 pango_win32_font_map_for_display (void)
@@ -324,7 +324,7 @@ pango_win32_family_get_type (void)
       };
       
       object_type = g_type_register_static (PANGO_TYPE_FONT_FAMILY,
-                                            "PangoWin32Family",
+                                            I_("PangoWin32Family"),
                                             &object_info, 0);
     }
   
@@ -963,7 +963,7 @@ pango_win32_face_get_type (void)
       };
       
       object_type = g_type_register_static (PANGO_TYPE_FONT_FACE,
-                                            "PangoWin32Face",
+                                            I_("PangoWin32Face"),
                                             &object_info, 0);
     }
   
@@ -997,7 +997,7 @@ pango_win32_font_entry_remove (PangoWin32Face *face,
  *
  * Obtains the font cache associated with the given font map.
  *
- * Return value: the #PangoWin32FontCache of @font_map.
+ * Returns: the #PangoWin32FontCache of @font_map.
  **/
 PangoWin32FontCache *
 pango_win32_font_map_get_font_cache (PangoFontMap *font_map)
