@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <string.h>
 #include <stdlib.h>
 #include <math.h>
@@ -34,8 +35,6 @@
 
 #define PANGO_X_UNKNOWN_FLAG 0x10000000
 
-#include "config.h"
-
 #define PANGO_TYPE_X_FONT              (pango_x_font_get_type ())
 #define PANGO_X_FONT(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_X_FONT, PangoXFont))
 #define PANGO_X_FONT_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), PANGO_TYPE_X_FONT, PangoXFontClass))
@@ -177,7 +176,7 @@ pango_x_get_context (Display *display)
   static gboolean registered_modules = FALSE;
   
   g_return_val_if_fail (display != NULL, NULL);  
-  
+
   if (!registered_modules)
     {
       registered_modules = TRUE;
@@ -247,7 +246,7 @@ pango_x_font_get_type (void)
       };
       
       object_type = g_type_register_static (PANGO_TYPE_FONT,
-                                            "PangoXFont",
+                                            I_("PangoXFont"),
                                             &object_info, 0);
     }
   
