@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <math.h>
 
 #include "pangoxft-render.h"
@@ -675,7 +676,7 @@ pango_xft_render_layout_line (XftDraw         *draw,
  * @draw:    an #XftDraw
  * @color:   the color in which to draw the glyphs
  * @font:    the font in which to draw the string
- * @matrix:  a #PangoMatrix, or %NULL to use an identity transformation
+ * @matrix: a #PangoMatrix, or %NULL to use an identity transformation
  * @glyphs:  the glyph string to draw
  * @x:       the x position of the start of the string (in Pango
  *           units in user space coordinates)
@@ -798,8 +799,8 @@ pango_xft_picture_render (Display          *display,
  * with the Xft library. You must call pango_xft_renderer_set_draw() before
  * using the renderer.
  *
- * Return value: the newly created #PangoXftRenderer, which should
- *               be freed with g_object_unref().
+ * Return value: the newly created #PangoXftRenderer object. Unref
+ * with g_object_unref() when you are finished with it.
  *
  * Since: 1.8
  **/
