@@ -19,6 +19,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
 #include <pango/pango-glyph.h>
 #include <pango/pango-engine-private.h>
 
@@ -26,7 +27,7 @@
  * pango_shape:
  * @text:      the text to process
  * @length:    the length (in bytes) of @text
- * @analysis:  #PangoAnalysis structure from PangoItemize
+ * @analysis:  #PangoAnalysis structure from pango_itemize()
  * @glyphs:    glyph string in which to store results
  *
  * Given a segment of text and the corresponding 
